@@ -14,8 +14,8 @@
 #
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
-
+from keycloak.authorization import Authorization
+from keycloak.exceptions import KeycloakAuthorizationConfigError, KeycloakInvalidTokenError
 from .exceptions import raise_error_from_response, KeycloakGetError, KeycloakSecretNotFound, \
     KeycloakRPTNotFound
 from .urls_patterns import (
@@ -30,34 +30,61 @@ from .urls_patterns import (
 )
 from .connection import ConnectionManager
 from jose import jwt
+import json
 
 
 class Keycloak:
 
     def __init__(self, server_url, client_id, realm_name, client_secret_key=None):
-        self.client_id = client_id
-        self.client_secret_key = client_secret_key
-        self.realm_name = realm_name
+        self._client_id = client_id
+        self._client_secret_key = client_secret_key
+        self._realm_name = realm_name
 
-        self.connection = ConnectionManager(base_url=server_url,
+        self._connection = ConnectionManager(base_url=server_url,
                                             headers={},
                                             timeout=60)
 
-    @property
-    def get_client_id(self):
-        return self.client_id
+        self._authorization = Authorization()
 
     @property
-    def get_client_secret_key(self):
-        return self.client_secret_key
+    def client_id(self):
+        return self._client_id
+
+    @client_id.setter
+    def client_id(self, value):
+        self._client_id = value
 
     @property
-    def get_realm_name(self):
-        return self.realm_name
+    def client_secret_key(self):
+        return self._client_secret_key
+
+    @client_secret_key.setter
+    def client_secret_key(self, value):
+        self._client_secret_key = value
 
     @property
-    def get_connection(self):
-        return self.connection
+    def realm_name(self):
+        return self._realm_name
+
+    @realm_name.setter
+    def realm_name(self, value):
+        self._realm_name = value
+
+    @property
+    def connection(self):
+        return self._connection
+
+    @connection.setter
+    def connection(self, value):
+        self._connection = value
+
+    @property
+    def authorization(self):
+        return self._authorization
+
+    @authorization.setter
+    def authorization(self, value):
+        self._authorization = value
 
     def _add_secret_key(self, payload):
         """
@@ -71,6 +98,9 @@ class Keycloak:
 
         return payload
 
+    def _build_name_role(self, role):
+        return self.client_id + "/" + role
+
     def well_know(self):
         """ The most important endpoint to understand is the well-known configuration
             endpoint. It lists endpoints and other configuration options relevant to
@@ -229,3 +259,52 @@ class Keycloak:
 
         return jwt.decode(token, key, algorithms=algorithms,
                           audience=self.client_id, **kwargs)
+
+    def load_authorization_config(self, path):
+        """
+        Load Keycloak settings (authorization)
+
+        :param path: settings file (json)
+        :return:
+        """
+        authorization_file = open(path, 'r')
+        authorization_json = json.loads(authorization_file.read())
+        self.authorization.load_config(authorization_json)
+        authorization_file.close()
+
+    def get_permissions(self, token):
+        """
+        Get permission by user token
+
+        :param token: user token
+        :return: permissions list
+        """
+
+        if not self.authorization.policies:
+            raise KeycloakAuthorizationConfigError(
+                "Keycloak settings not found. Load Authorization Keycloak settings."
+            )
+
+        token_info = self.instropect(token)
+
+        if not token_info['active']:
+            raise KeycloakInvalidTokenError(
+                "Token expired or invalid."
+            )
+
+        user_resources = token_info['resource_access'].get(self.client_id)
+
+        if not user_resources:
+            return None
+
+        permissions = []
+
+        for policy_name, policy in self.authorization.policies.items():
+            for role in user_resources['roles']:
+                if self._build_name_role(role) in policy.roles:
+                    permissions += policy.permissions
+
+        return list(set(permissions))
+
+
+
